import { DecoratorContext, Enum, EnumValue, Model, ModelProperty, Program } from "@typespec/compiler";
export declare const namespace = "Azure.ResourceManager.CommonTypes.Private";
export declare const ArmCommonTypesDefaultVersion = "v3";
export interface ArmCommonTypeRecord {
    name: string;
    kind: "definitions" | "parameters";
    version: string;
    basePath: string;
    referenceFile?: string;
}
export interface ArmCommonTypeRecords {
    records: {
        [key: string]: ArmCommonTypeRecord;
    };
    defaultKey?: string;
}
export declare function getCommonTypeRecords(program: Program, entity: Model | ModelProperty): ArmCommonTypeRecords;
interface ArmCommonTypeVersionSpec {
    version: string | EnumValue;
    isDefault: boolean;
}
/**
 * Refer an model property to be a common ARM parameter
 * @param {DecoratorContext} context DecoratorContext object
 * @param {Type} entity Decorator target type. Must be `Model`
 * @param {string?} definitionName Optional definition name
 * @param {string?} version Optional version
 * @param {string?} referenceFile Optional common file path
 * @returns void
 */
export declare function $armCommonParameter(context: DecoratorContext, entity: ModelProperty, parameterName?: string, version?: string | EnumValue | ArmCommonTypeVersionSpec, referenceFile?: string): void;
/**
 * Using ARM common definition for a Model
 * @param {DecoratorContext} context DecoratorContext object
 * @param {Type} entity Decorator target type. Must be `Model`
 * @param {string?} definitionName Optional definition name
 * @param {string?} version Optional version
 * @param {string?} referenceFile Optional common file path
 * @returns {void}
 */
export declare function $armCommonDefinition(context: DecoratorContext, entity: Model, definitionName?: string, version?: string | EnumValue | ArmCommonTypeVersionSpec, referenceFile?: string): void;
/**
 * Specify the ARM commont type version reference for a particular spec version or namespace.
 * @param DecoratorContext context DecoratorContext object
 * @param enumType entity Decorator target type. Must be `Model`
 * @returns void
 */
export declare function $armCommonTypesVersions(context: DecoratorContext, enumType: Enum): void;
export {};
//# sourceMappingURL=commontypes.private.decorators.d.ts.map