import { DecoratorContext, Interface, Model, ModelProperty, Operation, Program, Tuple } from "@typespec/compiler";
import { ArmResourceDetails } from "./resource.js";
export declare const namespace = "Azure.ResourceManager.Private";
export declare function $omitIfEmpty(context: DecoratorContext, entity: Model, propertyName: string): void;
export declare function $enforceConstraint(context: DecoratorContext, entity: Operation | Model, sourceType: Model, constraintType: Model): void;
export declare function $resourceBaseParametersOf(context: DecoratorContext, entity: Model, resourceType: Model): void;
export declare function $resourceParameterBaseFor(context: DecoratorContext, entity: ModelProperty, values: Tuple): void;
export declare function $defaultResourceKeySegmentName(context: DecoratorContext, entity: ModelProperty, resource: Model, keyName: string, segment: string): void;
export declare function getResourceParameterBases(program: Program, property: ModelProperty): string[] | undefined;
export declare function isResourceParameterBaseFor(program: Program, property: ModelProperty, resourceBaseType: string): boolean;
/**
 * This decorator dynamically assigns the serviceNamespace from the containing
 * namespace to the string literal value of the path parameter to which this
 * decorator is applied.  Its purpose is to dynamically insert the provider
 * namespace (e.g. 'Microsoft.CodeSigning') into the path parameter list.
 * @param {DecoratorContext} context DecoratorContext
 * @param {Type} target Target of this decorator. Must be a string `ModelProperty`.
 * @param {Type} resourceType Must be a `Model`.
 */
export declare function $assignProviderNameValue(context: DecoratorContext, target: ModelProperty, resourceType: Model): void;
/**
 * Update the ARM provider namespace for a given entity.
 * @param {DecoratorContext} context DecoratorContext
 * @param {Type} entity Entity to set namespace. Must be a `Operation`.
 * @returns
 */
export declare function $armUpdateProviderNamespace(context: DecoratorContext, entity: Operation): void;
/**
 * Check if an interface is extending the Azure.ResourceManager.Operations interface.
 */
export declare function isArmOperationsListInterface(program: Program, type: Interface): boolean;
/**
 * This decorator is used to identify ARM resource types and extract their
 * metadata.  It is *not* meant to be used directly by a spec author, it instead
 * gets implicitly applied when the spec author defines a model type in this form:
 *
 *   `model Server is TrackedResource<ServerProperties>;`
 *
 * The `TrackedResource<T>` type (and other associated base types) use the @armResource
 * decorator, so it also gets applied to the type which absorbs the `TrackedResource<T>`
 * definition by using the `is` keyword.
 */
export declare function $armResourceInternal(context: DecoratorContext, resourceType: Model, propertiesType: Model): void;
export declare function listArmResources(program: Program): ArmResourceDetails[];
export declare function getArmResource(program: Program, resourceType: Model): ArmResourceDetails | undefined;
export declare function $azureResourceBase(context: DecoratorContext, resourceType: Model): void;
export declare function isAzureResource(program: Program, resourceType: Model): boolean;
/**
 * Please DO NOT USE in RestAPI specs.
 * Internal decorator that deprecated direct usage of `x-ms-client-flatten` OpenAPI extension.
 * It will programatically enabled/disable client flattening with @flattenProperty with autorest
 * emitter flags to maintain compatibility in swagger.
 */
export declare function $conditionalClientFlatten(context: DecoratorContext, entity: ModelProperty): void;
export declare function isConditionallyFlattened(program: Program, entity: ModelProperty): boolean;
//# sourceMappingURL=private.decorators.d.ts.map